marktools.StemTremolo
=====================

.. abjad-lineage:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo

.. autoclass:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.attach
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.detach
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.lilypond_format
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.start_component
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.storage_format
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.tremolo_flags
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__call__
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__copy__
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__eq__
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__ne__
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__repr__
      ~abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__str__

Bases
-----

- :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.tremolo_flags
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.attach
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.detach
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__copy__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__repr__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__str__
   :noindex:
